/*******************************************************************************
* File Name: MP3_BSYNC.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "MP3_BSYNC.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 MP3_BSYNC__PORT == 15 && ((MP3_BSYNC__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: MP3_BSYNC_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void MP3_BSYNC_Write(uint8 value) 
{
    uint8 staticBits = (MP3_BSYNC_DR & (uint8)(~MP3_BSYNC_MASK));
    MP3_BSYNC_DR = staticBits | ((uint8)(value << MP3_BSYNC_SHIFT) & MP3_BSYNC_MASK);
}


/*******************************************************************************
* Function Name: MP3_BSYNC_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  MP3_BSYNC_DM_STRONG     Strong Drive 
*  MP3_BSYNC_DM_OD_HI      Open Drain, Drives High 
*  MP3_BSYNC_DM_OD_LO      Open Drain, Drives Low 
*  MP3_BSYNC_DM_RES_UP     Resistive Pull Up 
*  MP3_BSYNC_DM_RES_DWN    Resistive Pull Down 
*  MP3_BSYNC_DM_RES_UPDWN  Resistive Pull Up/Down 
*  MP3_BSYNC_DM_DIG_HIZ    High Impedance Digital 
*  MP3_BSYNC_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void MP3_BSYNC_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(MP3_BSYNC_0, mode);
}


/*******************************************************************************
* Function Name: MP3_BSYNC_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro MP3_BSYNC_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 MP3_BSYNC_Read(void) 
{
    return (MP3_BSYNC_PS & MP3_BSYNC_MASK) >> MP3_BSYNC_SHIFT;
}


/*******************************************************************************
* Function Name: MP3_BSYNC_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 MP3_BSYNC_ReadDataReg(void) 
{
    return (MP3_BSYNC_DR & MP3_BSYNC_MASK) >> MP3_BSYNC_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(MP3_BSYNC_INTSTAT) 

    /*******************************************************************************
    * Function Name: MP3_BSYNC_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 MP3_BSYNC_ClearInterrupt(void) 
    {
        return (MP3_BSYNC_INTSTAT & MP3_BSYNC_MASK) >> MP3_BSYNC_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
