/**************************************************************************************************
* File: MP3_driver.h
* File Type: C - Header File
* Project Name: BrmBrrrrm
* Company: (c) mikroElektronika, 2011
* Revision History:
*     20111118:
*       - modified for mikroMedia for XMEGA HW revision 1.10 (JK);
* Description:
*     This module contains a set of functions that are used for communication with
*     VS1053E mp3 codec.
*       MCU:             ATxmega128A1
*                        http://www.atmel.com/dyn/resources/prod_documents/doc8067.pdf
*       Dev.Board:       Mikromedia_for_XMEGA
*                        http://www.mikroe.com/eng/products/view/688/mikromedia-for-xmega/
*       Oscillator:      Internal Clock, 32.0000 MHz
*       SW:              mikroC PRO for AVR
*                        http://www.mikroe.com/eng/products/view/228/mikroc-pro-for-avr/
* NOTES:
*     Mp3 codec use SPI bus to communicate with MCU.
**************************************************************************************************/
#include <device.h>

#define MP3_CS0      MP3_CS_Write(0)
#define MP3_CS1      MP3_CS_Write(1)
#define MP3_RST0     MP3_RST_Write(0)
#define MP3_RST1     MP3_RST_Write(1)
#define MP3_BSYNC0   MP3_BSYNC_Write(0)
#define MP3_BSYNC1   MP3_BSYNC_Write(1)

#define MP3_DREQ     MP3_DREQ_Read()  
#define SD_CD        SD_CD_Read()

// VS1053E constants
#define WRITE_CODE              0x02
#define READ_CODE               0x03

#define SCI_BASE_ADDR           0x00
#define SCI_MODE_ADDR           0x00
#define SCI_STATUS_ADDR         0x01
#define SCI_BASS_ADDR           0x02
#define SCI_CLOCKF_ADDR         0x03
#define SCI_DECODE_TIME_ADDR    0x04
#define SCI_AUDATA_ADDR         0x05
#define SCI_WRAM_ADDR           0x06
#define SCI_WRAMADDR_ADDR       0x07
#define SCI_HDAT0_ADDR          0x08
#define SCI_HDAT1_ADDR          0x09
#define SCI_AIADDR_ADDR         0x0A
#define SCI_VOL_ADDR            0x0B
#define SCI_AICTRL0_ADDR        0x0C
#define SCI_AICTRL1_ADDR        0x0D
#define SCI_AICTRL2_ADDR        0x0E
#define SCI_AICTRL3_ADDR        0x0F

#define MP3_BUFFER_SIZE         512
#define MP3_BYTES_2_WRITE       32

// Writes one byte to MP3 SCI
void MP3_SCI_Write(uint8 address, uint16 data_in);
// Reads words_count words from MP3 SCI
void MP3_SCI_Read(uint8 start_address, uint8 words_count, uint16 *data_buffer);
// Write one byte to MP3 SDI
void MP3_SDI_Write(uint8 data_);
// Write 32 bytes to MP3 SDI
void MP3_SDI_Write_32(uint8 *data_);
// Set volume
void MP3_Set_Volume(uint8 left, uint8 right);
// Initialize VS1053 audio codec
void MP3_Init(void); 

/**************************************************************************************************
* End of File
**************************************************************************************************/