#ifndef ILI9341_H
#define ILI9341_H
 
#include "TFT.h"
#include <device.h>

#define  TFT_NOT_ROTATED   0
#define  TFT_ROTATED180    1

void (*TFT_Set_Index_Ptr)(uint8);
void (*TFT_Write_Command_Ptr)(uint8);
void (*TFT_Write_Data_Ptr)(uint16);
void (*TFT_Set_Address_Ptr)(uint16 x, uint16 y);

/**
  * @brief  Sets GRAM pointer to specific location.
  * @param  left : X offset in GRAM.
  * @param  top  : Y offset in GRAM.
  */
void TFT_Set_Address_ILI9341(uint16 x, uint16 y);

/**
  * @brief  Initializes controllers Reset routine along with the necessary settings afterwards
  */
void TFT_Reset_ILI9341();

/**
  * @brief  Initializes controller, and display size
  * @param  display_width : Actual width of a display.
  * @param  display_height : Actual width of a display.
  * @note   This routine includes call to TFT_Reset_ILI9341()
  */
void TFT_Init_ILI9341_8bit(uint16 display_width, uint16 display_height);

/**
  * @brief  Checks if display has been rotated by 180 degrees.
  * @retval 1 - if display is rotated. 
						0 - if display is not rotated (normal landscape or portrait orientation). 
  */
char Is_TFT_Rotated_180();

/**
  * @brief  Rotates the display by 180 degrees.
  * @param  Arotate : 0 - Sets display in normal landscape/portrait orientation
  										1 - Rotates the display by 180 degrees.		
  */
void TFT_Rotate_180(uint8 Arotate);

/**
  * @brief  Sets up internal TFT controllers register for folowing reading/writing
  * @param  index : Address of the register (range from 0x00 - 0xFF)
  */
void TFT_Set_Index(uint8 index);

/**
  * @brief  Writes value to the previously set register (via TFT_Set_Index)
  * @param  cmd : Value to be written to register.
  */
void TFT_Write_Command(uint8 cmd);

/**
  * @brief  Combines TFT_Set_Index and TFT_Write_Command
  * @param  index : Address of the register (range from 0x00 - 0xFF)
  * @param  value : Value to be written to register.
  */
void TFT_Set_Reg(uint8 index, uint8 value);

/**
  * @brief  Writes data directly to controllers GRAM.
  * @param  _data : Value to be written
  */
void TFT_Write_Data(uint16 _data);

#endif
