#ifndef RESIST_TOUCH_DRIVER_H
#define RESIST_TOUCH_DRIVER_H

#include <device.h> 


/**
  * @brief    * @brief  Sets TFT Touch Panel in default mode. Must not be ommited in the code!
  */
void TP_TFT_Set_Default_Mode();

/**
  * @brief  Rotates Touch Panel by 180 degrees.
  * @param  rotate : 	0 - sets the default orientation
  										1 - rotates touch panel by 180 degrees
  */
void TP_TFT_Rotate_180(uint8 rotate);

/**
  * @brief  initializes Touch panelwith default setting and appropriate display dimenstions (must be same as tft display dimenstions)
  * @param  display_width : Actual width of a display.
  * @param  display_height : Actual width of a display.
  */
void TP_TFT_Init(uint16 display_width, uint16 display_height);

/**
  * @brief  Acquire ADC value for the X axis of the touch panel
  * @retval ADC readings value.
  */
uint16 TP_TFT_GetX();

/**
  * @brief  Acquire ADC value for the Y axis of the touch panel
  * @retval ADC readings value.
  */
uint16 TP_TFT_GetY();

/**
  * @brief  Detects if touch panel has been pressed or not
  * @retval 0 - Touch panel not pressed.
						1 - Touch panel pressed.  
  */
uint8 TP_TFT_Press_Detect();

/**
  * @brief  If touch panel has been pressed acquire precise coordinates
  * @param  x_coordinate : pointer to X ccoordinate.
  * @param  y_coordinate : pointer to Y ccoordinate.
  * @retval 0 - Readings are within display range.
						1 - Invalid readings.  
  */
uint8 TP_TFT_Get_Coordinates(uint16 *x_coordinate, uint16 *y_coordinate);

/**
  * @brief  Calibrates the minimum of the touch panel. This procedure is used while calibrating touch panel. 
  					User should press corner of the display that gives minimal adc readings for both X and Y axiis
  */
void TP_TFT_Calibrate_Min();

/**
  * @brief  Calibrates the maximum of the touch panel. This procedure is used while calibrating touch panel. 
  					User should press corner of the display that gives maximal adc readings for both X and Y axiis
  */
void TP_TFT_Calibrate_Max();

/**
  * @brief  Reads calibration constants
  * @param  x_min : pointer to X min value
  * @param  x_max : pointer to Y min value
  * @param  y_min : pointer to X max value
  * @param  y_max : pointer to Y max value
  */
void TP_TFT_Get_Calibration_Consts(uint16 *x_min, uint16 *x_max, uint16 *y_min, uint16 *y_max);

/**
  * @brief  Set calibration constants
  * @param  x_min : X min value
  * @param  x_max : Y min value
  * @param  y_min : X max value
  * @param  y_max : Y max value
  */
void TP_TFT_Set_Calibration_Consts(uint16 x_min, uint16 x_max, uint16 y_min, uint16 y_max);

#endif