/*******************************************************************************
* File Name:    main.c
* Version:      1.00
* Authors:      John Otu
*
* Description:
*   This program is meant to demonstrate Oscilloscope functionality by sampling 
*   and scaling the input signal to be displayed on a graphic LCD.
*   Program uses mikroElektronika TFT and TP library, which is 
*	added as Dependency in Project options. Path to library header files must be 
*	included in Build Settings/Compiler.
*
*
********************************************************************************
* Copyright 2014, JohnOtu.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include <device.h>
#include "TFT.h"
//#include "MP3_driver.h"
#include "Fonts.h"
#include "FS.h"

/*uint8 MP3_Buffer[MP3_BUFFER_SIZE];
//uint8 MP3_run_test;
//char mp3_filename[20] = "Sound.mp3";
char sdVolName[10]; 
FS_FILE *pFile;
uint16 SPI_divider;

/**
  * @brief  Function draws test screen.
  */
void DrawMP3Screen(void) {
  TFT_Fill_Screen(CL_WHITE);
  TFT_Set_Pen(CL_BLACK, 1);
  TFT_Line(20, 220, 300, 220);
  TFT_Line(20,  30, 300,  30);
  TFT_Set_Font(HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text((uint8*)"MP3   CODEC   EXAMPLE", 50, 5);
  TFT_Set_Font(Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text((uint8*)"mikromedia for PSoC5LP", 19, 223);
  TFT_Set_Font(Verdana12x13_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text((uint8*)"www.mikroe.com", 200, 223);
  TFT_Set_Font(TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
}

/**
  * @brief  Function initializes VS1053 MP3 codec.
  
void MP3_Start(void) {
    MP3_CS1;
    MP3_RST1;  
    MP3_BSYNC0;    
    MP3_BSYNC1;
  */  
    TFT_Set_Pen(CL_WHITE, 1);
    TFT_Set_Brush(1, CL_WHITE, 0, 0, 0, 0);

    TFT_Write_Text((uint8*)"1. Initializing VS1053B decoder interface", 30, 70);

    MP3_Init();
    CyDelay(1000);
}

/**
  * @brief  Function runs the MP3 test.
  * @return Test status: 0 - skiped; 1 - pass; 2 - fail.
  */
void MP3_Test(uint8 *test) {
    uint32 i;
    uint32 file_size;
    int16 status;
    uint32 num_read;
  
    // Reset error flag
    *test = 0;
    
    if (SD_CD) {
        TFT_Write_Text((uint8*)"2. Insert microSD card", 30, 90);
        while(SD_CD);
        CyDelay(500);
        TFT_Set_Font(TFT_defaultFont, CL_WHITE, FO_HORIZONTAL);
        TFT_Write_Text((uint8*)"2. Insert microSD card", 30, 90);
        TFT_Set_Font(TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
    }
    
    TFT_Write_Text((uint8*)"2. microSD card inserted", 30, 90);
    CyDelay(1000);   

    TFT_Write_Text((uint8*)"3. Initializing MMC_FAT", 30, 110);
    FS_Init();
    if (FS_GetVolumeName(0u, &sdVolName[0], 9u) != -1) {
      pFile = FS_FOpen(mp3_filename, "r");
      if (pFile) {
        TFT_Write_Text((uint8*)"4. File Assigned", 30, 130);
        file_size = FS_GetFileSize(pFile); 
        if (file_size == 0xFFFFFFFF) 
          *test = 3;
        //Mmc_Fat_Reset(&file_size);          // Call Reset before file reading,
                                              //   procedure returns size of the file

        TFT_Write_Text((uint8*)"5. Play audio... :)", 30, 150);
       
        // send file blocks to MP3 SDI
        while (file_size > MP3_BUFFER_SIZE) {
          num_read = FS_Read(pFile, MP3_Buffer, MP3_BUFFER_SIZE);
          if (num_read != MP3_BUFFER_SIZE)
              *test = 4;
          // Slow down SPI clock!!!
          SPI_divider = emFile_Clock_1_GetDividerRegister();
          emFile_Clock_1_SetDividerRegister(5,0);
          for (i=0; i<MP3_BUFFER_SIZE/MP3_BYTES_2_WRITE; i++) {
              MP3_SDI_Write_32(MP3_Buffer + i*MP3_BYTES_2_WRITE);
          }
          // Speed up SPI clock!!!
          emFile_Clock_1_SetDividerRegister(SPI_divider,0);
          file_size -= MP3_BUFFER_SIZE;
      }

      num_read = FS_Read(pFile, MP3_Buffer, file_size);
      if (num_read != file_size)
          *test = 4;
      // Slow down SPI clock!!!
      SPI_divider = emFile_Clock_1_GetDividerRegister();
      emFile_Clock_1_SetDividerRegister(5,0);
      for (i=0; i<file_size; i++) {
          MP3_SDI_Write(MP3_Buffer[i]);
      }
      // Speed up SPI clock!!!
      emFile_Clock_1_SetDividerRegister(SPI_divider,0);

      status = FS_FClose(pFile);
      TFT_Write_Text((uint8*)"6. Finish!", 30, 170);
        
      }
      else {
        TFT_Write_Text((uint8*)"4. File not assigned", 30, 130);
        *test = 2;
      }
    }
    else {
      TFT_Write_Text((uint8*)"4. MMC FAT not initialized", 30, 130);
      *test = 2;
    }
}

/**
  * @brief  Initializes microcontroller peripherals and I/O pins.
  */
void Init_MCU() {
    TFT_BLED_Write(1);
    TFT_Set_Default_Mode();
    TFT_Init_ILI9341_8bit(320, 240);
    
    emFile_SPI0_Start();  
    emFile_Clock_1_SetDividerRegister(5,0);      // Set divider to 6
}

/**
  * @brief  Main function.
  */
void main() {
    Init_MCU();
    
    DrawMP3Screen();

    MP3_Start();

    MP3_Test(&MP3_run_test);
    
    // Infinite loop
    while (1) {
    }
}